@@ -1,5 +1,5 @@
-from adumo.exceptions import AdumoInvalidCard, AdumoInvalidRequestedAmount
-from decimal import Decimal
+from adumo.exceptions import AdumoInvalidCard
+
 
 class Card:
     def __init__(
@@ -53,22 +53,3 @@ class AccountHolder:
 
     def __str__(self):
         return f"{self.first_name} {self.last_name}"
-
-
-class RequestedAmount:
-    def __init__(self, amount):
-        self.amount = Decimal(amount).quantize(Decimal('.00'))
-
-        self.validate()
-
-    def __repr__(self):
-        return str(self.amount)
-
-    def validate(self):
-        integer_part, fractional_part = str(self.amount).split('.')
-        if len(integer_part) > 18:
-            raise AdumoInvalidRequestedAmount('integer_part length should be less than 18')
-
-        if len(fractional_part) > 2:
-            raise AdumoInvalidRequestedAmount('fractional_part length should be less than 2')
-
